extended_script_info_message_parser

Function extended_script_info_message_parser 

pub fn extended_script_info_message_parser<'src>() -> impl Parser<'src, &'src str, SystemMessage, Err<Rich<'src, char>>>
parse a system message with extended script info usually this should follow a line with regular script info containing the object name

Errors

returns an error if the string could not be parsed