items_successfully_shared_message_parser

Function items_successfully_shared_message_parser 

pub fn items_successfully_shared_message_parser<'src>() -> impl Parser<'src, &'src str, SystemMessage, Err<Rich<'src, char>>>
parse a system message about items being successfully shared

Errors

returns an error if the string could not be parsed