object_gave_object_message_parser

Function object_gave_object_message_parser 

pub fn object_gave_object_message_parser<'src>() -> impl Parser<'src, &'src str, SystemMessage, Err<Rich<'src, char>>>
parse a system message about an object giving the current avatar an object

Errors

returns an error if the string could not be parsed