simulator_version_message_parser

Function simulator_version_message_parser 

pub fn simulator_version_message_parser<'src>() -> impl Parser<'src, &'src str, SystemMessage, Err<Rich<'src, char>>>
parse a system message about a different simulator version

Errors

returns an error if the string could not be parsed