pub fn declined_given_object_message_parser<'src>() -> impl Parser<'src, &'src str, SystemMessage, Err<Rich<'src, char>>>Expand description
parse a system message about declining an object given to you
Errors
returns an error if the string could not be parsed